@@ -2,13 +2,6 @@ import numpy as np
 
 from typing import List, Tuple, Optional
 
-import json
-
-
-class DictSerializable:
-    def to_dict(self):
-        return json.loads(json.dumps(self, default=lambda o: o.__dict__))
-
 
 class DataPacket:
     def __init__(self, headers=None):
@@ -27,19 +20,25 @@ class DataPacket:
         self.headers[name] = value
 
 
+class StringPacket(DataPacket):
+    def __init__(self, data: str, headers=None):
+        super().__init__(headers)
+        self.data = data
+
+
 class ByteDataPacket(DataPacket):
     def __init__(self, data: bytes, headers=None):
         super().__init__(headers)
         self.data = data
 
 
-class TranscriptionPacket(DataPacket, DictSerializable):
+class TranscriptionPacket(DataPacket):
     def __init__(self, transcript: str, headers=None):
         super().__init__(headers)
         self.transcript = transcript
 
 
-class Word(DictSerializable):
+class Word:
     def __init__(self, word: str, start_time_millis: float, end_time_millis: float, speaker: Optional[int] = None,
                  confidence: float = 0):
         self.word: str = word
